{
  am_pm_abbreviated => [
    "\N{U+0bae}\N{U+0bc1}\N{U+0bb1}\N{U+0bcd}\N{U+0baa}\N{U+0b95}\N{U+0bb2}\N{U+0bcd}",
    "\N{U+0baa}\N{U+0bbf}\N{U+0bb1}\N{U+0bcd}\N{U+0baa}\N{U+0b95}\N{U+0bb2}\N{U+0bcd}",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E a h:mm",
    Ehms => "E a h:mm:ss",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "dd-MM, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
    "MMMMW-count-other" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
    MMMMd => "d MMMM",
    MMMd => "MMM d",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "a h",
    hm => "a h:mm",
    hms => "a h:mm:ss",
    hmsv => "a h:mm:ss v",
    hmv => "a h:mm v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0b86}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbf}\N{U+0ba9}\N{U+0bcd} w -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
    "yw-count-other" => "Y \N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0b86}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbf}\N{U+0ba9}\N{U+0bcd} w -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
  },
  code => "ta-MY",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} \N{U+2019}\N{U+0b85}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bc1}\N{U+2019} {0}",
  datetime_format_long => "{1} \N{U+2019}\N{U+0b85}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bc1}\N{U+2019} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0ba4}\N{U+0bbf}\N{U+0b99}\N{U+0bcd}.",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0bb5}\N{U+0bcd}.",
    "\N{U+0baa}\N{U+0bc1}\N{U+0ba4}.",
    "\N{U+0bb5}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}.",
    "\N{U+0bb5}\N{U+0bc6}\N{U+0bb3}\N{U+0bcd}.",
    "\N{U+0b9a}\N{U+0ba9}\N{U+0bbf}",
    "\N{U+0b9e}\N{U+0bbe}\N{U+0baf}\N{U+0bbf}.",
  ],
  day_format_narrow => [
    "\N{U+0ba4}\N{U+0bbf}",
    "\N{U+0b9a}\N{U+0bc6}",
    "\N{U+0baa}\N{U+0bc1}",
    "\N{U+0bb5}\N{U+0bbf}",
    "\N{U+0bb5}\N{U+0bc6}",
    "\N{U+0b9a}",
    "\N{U+0b9e}\N{U+0bbe}",
  ],
  day_format_wide => [
    "\N{U+0ba4}\N{U+0bbf}\N{U+0b99}\N{U+0bcd}\N{U+0b95}\N{U+0bb3}\N{U+0bcd}",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0bb5}\N{U+0bcd}\N{U+0bb5}\N{U+0bbe}\N{U+0baf}\N{U+0bcd}",
    "\N{U+0baa}\N{U+0bc1}\N{U+0ba4}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0bb5}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}\N{U+0bb4}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0bb5}\N{U+0bc6}\N{U+0bb3}\N{U+0bcd}\N{U+0bb3}\N{U+0bbf}",
    "\N{U+0b9a}\N{U+0ba9}\N{U+0bbf}",
    "\N{U+0b9e}\N{U+0bbe}\N{U+0baf}\N{U+0bbf}\N{U+0bb1}\N{U+0bc1}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0ba4}\N{U+0bbf}\N{U+0b99}\N{U+0bcd}.",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0bb5}\N{U+0bcd}.",
    "\N{U+0baa}\N{U+0bc1}\N{U+0ba4}.",
    "\N{U+0bb5}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}.",
    "\N{U+0bb5}\N{U+0bc6}\N{U+0bb3}\N{U+0bcd}.",
    "\N{U+0b9a}\N{U+0ba9}\N{U+0bbf}",
    "\N{U+0b9e}\N{U+0bbe}\N{U+0baf}\N{U+0bbf}.",
  ],
  day_stand_alone_narrow => [
    "\N{U+0ba4}\N{U+0bbf}",
    "\N{U+0b9a}\N{U+0bc6}",
    "\N{U+0baa}\N{U+0bc1}",
    "\N{U+0bb5}\N{U+0bbf}",
    "\N{U+0bb5}\N{U+0bc6}",
    "\N{U+0b9a}",
    "\N{U+0b9e}\N{U+0bbe}",
  ],
  day_stand_alone_wide => [
    "\N{U+0ba4}\N{U+0bbf}\N{U+0b99}\N{U+0bcd}\N{U+0b95}\N{U+0bb3}\N{U+0bcd}",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0bb5}\N{U+0bcd}\N{U+0bb5}\N{U+0bbe}\N{U+0baf}\N{U+0bcd}",
    "\N{U+0baa}\N{U+0bc1}\N{U+0ba4}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0bb5}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}\N{U+0bb4}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0bb5}\N{U+0bc6}\N{U+0bb3}\N{U+0bcd}\N{U+0bb3}\N{U+0bbf}",
    "\N{U+0b9a}\N{U+0ba9}\N{U+0bbf}",
    "\N{U+0b9e}\N{U+0bbe}\N{U+0baf}\N{U+0bbf}\N{U+0bb1}\N{U+0bc1}",
  ],
  era_abbreviated => [
    "\N{U+0b95}\N{U+0bbf}.\N{U+0bae}\N{U+0bc1}.",
    "\N{U+0b95}\N{U+0bbf}.\N{U+0baa}\N{U+0bbf}.",
  ],
  era_narrow => [
    "\N{U+0b95}\N{U+0bbf}.\N{U+0bae}\N{U+0bc1}.",
    "\N{U+0b95}\N{U+0bbf}.\N{U+0baa}\N{U+0bbf}.",
  ],
  era_wide => [
    "\N{U+0b95}\N{U+0bbf}\N{U+0bb1}\N{U+0bbf}\N{U+0bb8}\N{U+0bcd}\N{U+0ba4}\N{U+0bc1}\N{U+0bb5}\N{U+0bc1}\N{U+0b95}\N{U+0bcd}\N{U+0b95}\N{U+0bc1} \N{U+0bae}\N{U+0bc1}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0b85}\N{U+0ba9}\N{U+0bcd}\N{U+0ba9}\N{U+0bcb} \N{U+0b9f}\N{U+0bcb}\N{U+0bae}\N{U+0bbf}\N{U+0ba9}\N{U+0bbf}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tamil",
  month_format_abbreviated => [
    "\N{U+0b9c}\N{U+0ba9}.",
    "\N{U+0baa}\N{U+0bbf}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0bae}\N{U+0bbe}\N{U+0bb0}\N{U+0bcd}.",
    "\N{U+0b8f}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0bb2}\N{U+0bc8}",
    "\N{U+0b86}\N{U+0b95}.",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0b85}\N{U+0b95}\N{U+0bcd}.",
    "\N{U+0ba8}\N{U+0bb5}.",
    "\N{U+0b9f}\N{U+0bbf}\N{U+0b9a}.",
  ],
  month_format_narrow => [
    "\N{U+0b9c}",
    "\N{U+0baa}\N{U+0bbf}",
    "\N{U+0bae}\N{U+0bbe}",
    "\N{U+0b8f}",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}",
    "\N{U+0b9c}\N{U+0bc2}",
    "\N{U+0b86}",
    "\N{U+0b9a}\N{U+0bc6}",
    "\N{U+0b85}",
    "\N{U+0ba8}",
    "\N{U+0b9f}\N{U+0bbf}",
  ],
  month_format_wide => [
    "\N{U+0b9c}\N{U+0ba9}\N{U+0bb5}\N{U+0bb0}\N{U+0bbf}",
    "\N{U+0baa}\N{U+0bbf}\N{U+0baa}\N{U+0bcd}\N{U+0bb0}\N{U+0bb5}\N{U+0bb0}\N{U+0bbf}",
    "\N{U+0bae}\N{U+0bbe}\N{U+0bb0}\N{U+0bcd}\N{U+0b9a}\N{U+0bcd}",
    "\N{U+0b8f}\N{U+0baa}\N{U+0bcd}\N{U+0bb0}\N{U+0bb2}\N{U+0bcd}",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0bb2}\N{U+0bc8}",
    "\N{U+0b86}\N{U+0b95}\N{U+0bb8}\N{U+0bcd}\N{U+0b9f}\N{U+0bcd}",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0baa}\N{U+0bcd}\N{U+0b9f}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0b85}\N{U+0b95}\N{U+0bcd}\N{U+0b9f}\N{U+0bcb}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0ba8}\N{U+0bb5}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0b9f}\N{U+0bbf}\N{U+0b9a}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0b9c}\N{U+0ba9}.",
    "\N{U+0baa}\N{U+0bbf}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0bae}\N{U+0bbe}\N{U+0bb0}\N{U+0bcd}.",
    "\N{U+0b8f}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0bb2}\N{U+0bc8}",
    "\N{U+0b86}\N{U+0b95}.",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0baa}\N{U+0bcd}.",
    "\N{U+0b85}\N{U+0b95}\N{U+0bcd}.",
    "\N{U+0ba8}\N{U+0bb5}.",
    "\N{U+0b9f}\N{U+0bbf}\N{U+0b9a}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+0b9c}",
    "\N{U+0baa}\N{U+0bbf}",
    "\N{U+0bae}\N{U+0bbe}",
    "\N{U+0b8f}",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}",
    "\N{U+0b9c}\N{U+0bc2}",
    "\N{U+0b86}",
    "\N{U+0b9a}\N{U+0bc6}",
    "\N{U+0b85}",
    "\N{U+0ba8}",
    "\N{U+0b9f}\N{U+0bbf}",
  ],
  month_stand_alone_wide => [
    "\N{U+0b9c}\N{U+0ba9}\N{U+0bb5}\N{U+0bb0}\N{U+0bbf}",
    "\N{U+0baa}\N{U+0bbf}\N{U+0baa}\N{U+0bcd}\N{U+0bb0}\N{U+0bb5}\N{U+0bb0}\N{U+0bbf}",
    "\N{U+0bae}\N{U+0bbe}\N{U+0bb0}\N{U+0bcd}\N{U+0b9a}\N{U+0bcd}",
    "\N{U+0b8f}\N{U+0baa}\N{U+0bcd}\N{U+0bb0}\N{U+0bb2}\N{U+0bcd}",
    "\N{U+0bae}\N{U+0bc7}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}",
    "\N{U+0b9c}\N{U+0bc2}\N{U+0bb2}\N{U+0bc8}",
    "\N{U+0b86}\N{U+0b95}\N{U+0bb8}\N{U+0bcd}\N{U+0b9f}\N{U+0bcd}",
    "\N{U+0b9a}\N{U+0bc6}\N{U+0baa}\N{U+0bcd}\N{U+0b9f}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0b85}\N{U+0b95}\N{U+0bcd}\N{U+0b9f}\N{U+0bcb}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0ba8}\N{U+0bb5}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
    "\N{U+0b9f}\N{U+0bbf}\N{U+0b9a}\N{U+0bae}\N{U+0bcd}\N{U+0baa}\N{U+0bb0}\N{U+0bcd}",
  ],
  name => "Tamil Malaysia",
  native_language => "\N{U+0ba4}\N{U+0bae}\N{U+0bbf}\N{U+0bb4}\N{U+0bcd}",
  native_name => "\N{U+0ba4}\N{U+0bae}\N{U+0bbf}\N{U+0bb4}\N{U+0bcd} \N{U+0bae}\N{U+0bb2}\N{U+0bc7}\N{U+0b9a}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}",
  native_script => undef,
  native_territory => "\N{U+0bae}\N{U+0bb2}\N{U+0bc7}\N{U+0b9a}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
    "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
  ],
  script => undef,
  territory => "Malaysia",
  time_format_full => "a h:mm:ss zzzz",
  time_format_long => "a h:mm:ss z",
  time_format_medium => "a h:mm:ss",
  time_format_short => "a h:mm",
  variant => undef,
  version => 35,
}
